@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -129,6 +129,16 @@ class PathNotFound(FileOperationError):
             self.original_error)
 
 
+@six.python_2_unicode_compatible
+class BatchAlreadyExecuted(RattailError):
+
+    def __init__(self, batch):
+        self.batch = batch
+
+    def __str__(self):
+        return "Batch is already executed: {}".format(self.batch)
+
+
 class LabelPrintingError(Exception):
 
     pass
