@@ -94,6 +94,7 @@ class FromRattailToRattailVersions(FromRattailHandler, ToRattailHandler):
         importers['ProductCost'] = ProductCostImporter
         importers['ProductPrice'] = ProductPriceImporter
         importers['LabelProfile'] = LabelProfileImporter
+        importers['IFPS_PLU'] = IFPS_PLUImporter
         return importers
 
     def begin_local_transaction(self):
@@ -302,3 +303,6 @@ class ProductPriceImporter(VersionImporter):
 
 class LabelProfileImporter(VersionImporter):
     host_model_class = model.LabelProfile
+
+class IFPS_PLUImporter(VersionImporter):
+    host_model_class = model.IFPS_PLU
