@@ -1,9 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 
 from __future__ import unicode_literals, absolute_import
 
 import unittest
 
+import six
+
 from rattail import exceptions
 
 
@@ -14,14 +16,8 @@ class TestRecipientsNotFound(unittest.TestCase):
         exc = exceptions.RecipientsNotFound('testing')
         self.assertEqual(exc.key, 'testing')
 
-    def test_str(self):
-        exc = exceptions.RecipientsNotFound('testing')
-        self.assertEqual(str(exc),
-                         b"No recipients found in config for 'testing' emails.  Please set "
-                         "'testing.to' (or 'default.to') in the [rattail.mail] section.")
-
     def test_unicode(self):
         exc = exceptions.RecipientsNotFound('testing')
-        self.assertEqual(unicode(exc),
+        self.assertEqual(six.text_type(exc),
                          "No recipients found in config for 'testing' emails.  Please set "
                          "'testing.to' (or 'default.to') in the [rattail.mail] section.")
